@@ -4,10 +4,8 @@ from fractions import Fraction
 from logging import warning
 from json import JSONEncoder
 from sys import version
-
 from decimal import Decimal
-
-from .utils import hashodict
+from .utils import hashodict, call_with_optional_kwargs
 
 
 class TricksEncoder(JSONEncoder):
@@ -18,7 +16,7 @@ class TricksEncoder(JSONEncoder):
 	Each encoder should make any appropriate changes and return an object,
 	changed or not. This will be passes to the other encoders.
 	"""
-	def __init__(self, obj_encoders=None, silence_typeerror=False, **json_kwargs):
+	def __init__(self, obj_encoders=None, silence_typeerror=False, primitives=False, **json_kwargs):
 		"""
 		:param obj_encoders: An iterable of functions or encoder instances to try.
 		:param silence_typeerror: If set to True, ignore the TypeErrors that Encoder instances throw (default False).
@@ -27,6 +25,7 @@ class TricksEncoder(JSONEncoder):
 		if obj_encoders:
 			self.obj_encoders = list(obj_encoders)
 		self.silence_typeerror = silence_typeerror
+		self.primitives = primitives
 		super(TricksEncoder, self).__init__(**json_kwargs)
 
 	def default(self, obj, *args, **kwargs):
@@ -35,7 +34,7 @@ class TricksEncoder(JSONEncoder):
 		all the encoders with the previous one's output used as input.
 
 		It works for Encoder instances, but they are expected not to throw
-		TypeErrorfor unrecognized types (the super method does that by default).
+		`TypeError` for unrecognized types (the super method does that by default).
 
 		It never calls the `super` method so if there are non-primitive types
 		left at the end, you'll get an encoding error.
@@ -43,14 +42,13 @@ class TricksEncoder(JSONEncoder):
 		prev_id = id(obj)
 		for encoder in self.obj_encoders:
 			if hasattr(encoder, 'default'):
-				# hope no TypeError is thrown
 				try:
-					obj = encoder.default(obj)
+					obj = call_with_optional_kwargs(encoder.default, obj, primitives=self.primitives)
 				except TypeError as err:
 					if not self.silence_typeerror:
 						raise
 			elif hasattr(encoder, '__call__'):
-				obj = encoder(obj)
+				obj = call_with_optional_kwargs(encoder, obj, primitives=self.primitives)
 			else:
 				raise TypeError('`obj_encoder` {0:} does not have `default` method and is not callable'.format(encoder))
 		if id(obj) == prev_id:
@@ -59,13 +57,15 @@ class TricksEncoder(JSONEncoder):
 		return obj
 
 
-def json_date_time_encode(obj):
+def json_date_time_encode(obj, primitives=False):
 	"""
 	Encode a date, time, datetime or timedelta to a string of a json dictionary, including optional timezone.
 
 	:param obj: date/time/datetime/timedelta obj
 	:return: (dict) json primitives representation of date, time, datetime or timedelta
 	"""
+	if primitives and isinstance(obj, (date, time, datetime)):
+		return obj.isoformat()
 	if isinstance(obj, datetime):
 		dct = hashodict([('__datetime__', None), ('year', obj.year), ('month', obj.month),
 			('day', obj.day), ('hour', obj.hour), ('minute', obj.minute),
@@ -80,8 +80,11 @@ def json_date_time_encode(obj):
 		if obj.tzinfo:
 			dct['tzinfo'] = obj.tzinfo.zone
 	elif isinstance(obj, timedelta):
-		dct = hashodict([('__timedelta__', None), ('days', obj.days), ('seconds', obj.seconds),
-			('microseconds', obj.microseconds)])
+		if primitives:
+			return obj.total_seconds()
+		else:
+			dct = hashodict([('__timedelta__', None), ('days', obj.days), ('seconds', obj.seconds),
+				('microseconds', obj.microseconds)])
 	else:
 		return obj
 	for key, val in tuple(dct.items()):
@@ -90,7 +93,7 @@ def json_date_time_encode(obj):
 	return dct
 
 
-def class_instance_encode(obj):
+def class_instance_encode(obj, primitives=False):
 	"""
 	Encodes a class instance to json. Note that it can only be recovered if the environment allows the class to be
 	imported in the same way.
@@ -118,11 +121,14 @@ def class_instance_encode(obj):
 			attrs = obj.__json_encode__()
 		else:
 			attrs = hashodict(obj.__dict__.items())
-		return hashodict((('__instance_type__', (mod, name)), ('attributes', attrs)))
+		if primitives:
+			return attrs
+		else:
+			return hashodict((('__instance_type__', (mod, name)), ('attributes', attrs)))
 	return obj
 
 
-def json_complex_encode(obj):
+def json_complex_encode(obj, primitives=False):
 	"""
 	Encode a complex number as a json dictionary of it's real and imaginary part.
 
@@ -130,21 +136,35 @@ def json_complex_encode(obj):
 	:return: (dict) json primitives representation of `obj`
 	"""
 	if isinstance(obj, complex):
-		return hashodict(__complex__=[obj.real, obj.imag])
+		if primitives:
+			return [obj.real, obj.imag]
+		else:
+			return hashodict(__complex__=[obj.real, obj.imag])
 	return obj
 
 
-def numeric_types_encode(obj):
+def numeric_types_encode(obj, primitives=False):
+	"""
+	Encode Decimal and Fraction.
+	
+	:param primitives: Encode decimals and fractions as standard floats. You may lose precision. If you do this, you may need to enable `allow_nan` (decimals always allow NaNs but floats do not).
+	"""
 	if isinstance(obj, Decimal):
-		return {
-			'__decimal__': str(obj.canonical()),
-		}
+		if primitives:
+			return float(obj)
+		else:
+			return {
+				'__decimal__': str(obj.canonical()),
+			}
 	if isinstance(obj, Fraction):
-		return {
-			'__fraction__': True,
-			'numerator': obj.numerator,
-			'denominator': obj.denominator,
-		}
+		if primitives:
+			return float(obj)
+		else:
+			return hashodict((
+				('__fraction__', True),
+				('numerator', obj.numerator),
+				('denominator', obj.denominator),
+			))
 	return obj
 
 
@@ -162,7 +182,7 @@ class ClassInstanceEncoder(JSONEncoder):
 		return super(ClassInstanceEncoder, self).default(obj, *args, **kwargs)
 
 
-def json_set_encode(obj):
+def json_set_encode(obj, primitives=False):
 	"""
 	Encode python sets as dictionary with key __set__ and a list of the values.
 
@@ -173,7 +193,10 @@ def json_set_encode(obj):
 			repr = sorted(obj)
 		except Exception:
 			repr = list(obj)
-		return hashodict(__set__=repr)
+		if primitives:
+			return repr
+		else:
+			return hashodict(__set__=repr)
 	return obj
 
 
